# Contributing to MyCoder Agent

## Development Guidelines

Key points:

- Run build, test, and lint before submitting changes
- Use TypeScript types over interfaces
- Maintain test coverage
- Keep documentation updated
- Use the logger system for output

## Development Setup

```bash
# Clone the repository
git clone https://github.com/bhouston/mycoder.git

# Change directory
cd mycoder

# Install dependencies
pnpm install

# Create a .env with your API key
echo "ANTHROPIC_API_KEY=[your-api-key]" > .env
```

### Development Commands

- `pnpm run build` - Build the TypeScript code
- `pnpm test` - Run tests
- `pnpm run typecheck` - Run TypeScript type checking
- `pnpm run clean` - Clean build artifacts

## Coding Style

### Terse and Simple

Favor a terse coding style that focuses on simplicity and readability.

### Prefer Types over Interfaces

When writing types please use type rather than interfaces as they are more robust.

### Use Logger for Output

The project uses a hierarchical logging system (Logger) that helps distinguish between different agents and tools in the output:

- `verbose`: Detailed debug information (dimmed version of agent/tool color)
- `info`: Normal operational messages (colored according to agent/tool color)
- `warn`: Warning messages (yellow)
- `error`: Error messages (red)

## Tool Development

When developing new tools:

1. Place them in the appropriate category directory under `src/tools/`
2. Ensure proper TypeScript types and documentation
3. Add tests for the new tool
4. Update tool documentation

## Testing

- Add tests for new functionality
- Ensure existing tests pass
- Maintain high test coverage
- Write meaningful test descriptions

## Documentation

Keep documentation up-to-date when making changes:

- Update README.md with new features or changes
- Document new tools and their usage
- Update type definitions and comments
- Add examples where helpful
